pub struct WindowEventInfo {
pub change: WindowChange,
pub container: Node,
}Expand description
Data for WindowEvent.
Fields
change: WindowChangeIndicates the type of change
container: NodeThe window’s parent container. Be aware that for the “new” event, the container will hold the initial name of the newly reparented window (e.g. if you run urxvt with a shell that changes the title, you will still at this point get the window title as “urxvt”).